@@ -14,7 +14,7 @@
 ***********************************************************************/
 
 static char const RCSID[] =
-"$Id: md-mx-ctrl.c,v 1.28 2005/06/24 14:38:00 dfs Exp $";
+"$Id: md-mx-ctrl.c 11287 2006-04-27 15:17:02Z dfs $";
 
 #include "config.h"
 #define SMALLBUF 16384
@@ -374,6 +374,51 @@ doBarStatus(char const *sock)
     return EXIT_SUCCESS;
 }
 
+static int
+doHLoad(char const *rawcmd,
+	char const *msgstr,
+	char const *scanstr,
+	char const *sock)
+{
+    char ans[4096];
+    int msgs_1, msgs_4, msgs_12, msgs_24;
+    int secs_1, secs_4, secs_12, secs_24;
+    double avg_1, avg_4, avg_12, avg_24;
+    double mps_1, mps_4, mps_12, mps_24;
+    double ams_1, ams_4, ams_12, ams_24;
+
+    char persec[256];
+    char ms[256];
+    sprintf(persec, "%s/Sec", msgstr);
+    sprintf(ms, "Avg ms/%s", scanstr);
+
+    if (MXCommand(sock, rawcmd, ans, sizeof(ans)) < 0) {
+	return EXIT_FAILURE;
+    }
+
+    sscanf(ans, "%d %d %d %d %lf %lf %lf %lf %lf %lf %lf %lf %d %d %d %d",
+	   &msgs_1, &msgs_4, &msgs_12, &msgs_24,
+	   &avg_1, &avg_4, &avg_12, &avg_24,
+	   &ams_1, &ams_4, &ams_12, &ams_24,
+	   &secs_1, &secs_4, &secs_12, &secs_24);
+
+    if (secs_1) mps_1 = (double) msgs_1 / (double) secs_1;
+    else        mps_1 = 0;
+    if (secs_4) mps_4 = (double) msgs_4 / (double) secs_4;
+    else        mps_4 = 0;
+    if (secs_12) mps_12 = (double) msgs_12 / (double) secs_12;
+    else        mps_12 = 0;
+    if (secs_24) mps_24 = (double) msgs_24 / (double) secs_24;
+    else        mps_24 = 0;
+
+    printf("%6s %17s %15s %15s %s\n", "Load", msgstr, persec, ms, "  Avg Busy Slaves");
+    printf("%6s %15d %15.2f %15.1f %15.2f\n", " 1h", msgs_1, mps_1, ams_1, avg_1);
+    printf("%6s %15d %15.2f %15.1f %15.2f\n", " 4h", msgs_4, mps_4, ams_4, avg_4);
+    printf("%6s %15d %15.2f %15.1f %15.2f\n", "12h", msgs_12, mps_12, ams_12, avg_12);
+    printf("%6s %15d %15.2f %15.1f %15.2f\n", "24h", msgs_24, mps_24, ams_24, avg_24);
+    return EXIT_SUCCESS;
+}
+
 static int
 doLoad(char const *rawcmd,
        char const *msgstr,
@@ -502,6 +547,14 @@ process(char const *sock, char const *cmd) {
 	return doCmd(sock, "load-senderok\n", 0);
     } else if (!strcmp(cmd, "rawload-recipok\n")) {
 	return doCmd(sock, "load-recipok\n", 0);
+    } else if (!strcmp(cmd, "rawhload\n")) {
+	return doCmd(sock, "hload\n", 0);
+    } else if (!strcmp(cmd, "rawhload-relayok\n")) {
+	return doCmd(sock, "hload-relayok\n", 0);
+    } else if (!strcmp(cmd, "rawhload-senderok\n")) {
+	return doCmd(sock, "hload-senderok\n", 0);
+    } else if (!strcmp(cmd, "rawhload-recipok\n")) {
+	return doCmd(sock, "hload-recipok\n", 0);
     } else if (!strcmp(cmd, "load\n")) {
 	return doLoad(cmd, "Msgs", "Scan", sock);
     } else if (!strcmp(cmd, "load-relayok\n")) {
@@ -510,6 +563,14 @@ process(char const *sock, char const *cmd) {
 	return doLoad(cmd, "MAIL", "MAIL", sock);
     } else if (!strcmp(cmd, "load-recipok\n")) {
 	return doLoad(cmd, "RCPT", "RCPT", sock);
+    } else if (!strcmp(cmd, "hload\n")) {
+	return doHLoad(cmd, "Msgs", "Scan", sock);
+    } else if (!strcmp(cmd, "hload-relayok\n")) {
+	return doHLoad(cmd, "Conn", "Conn", sock);
+    } else if (!strcmp(cmd, "hload-senderok\n")) {
+	return doHLoad(cmd, "MAIL", "MAIL", sock);
+    } else if (!strcmp(cmd, "hload-recipok\n")) {
+	return doHLoad(cmd, "RCPT", "RCPT", sock);
     } else {
 	return doCmd(sock, cmd, 1);
     }
