@@ -16,7 +16,7 @@
 ***********************************************************************/
 
 static char const RCSID[] =
-"$Id: mimedefang.c,v 1.242 2006/01/28 01:59:43 dfs Exp $";
+"$Id: mimedefang.c 11128 2006-04-06 20:17:21Z dfs $";
 
 #define _BSD_SOURCE 1
 
@@ -402,8 +402,11 @@ mfconnect(SMFICTX *ctx, char *hostname, _SOCK_ADDR *sa)
 	    DEBUG_EXIT("mfconnect", __LINE__, "SMFIS_TEMPFAIL");
 	    return SMFIS_TEMPFAIL;
 	}
-
-	is_local = is_localhost(sa);
+	if (!sa) {
+	    is_local = 1;
+	} else {
+	    is_local = is_localhost(sa);
+	}
 
 	if (slavesReservedForLoopback >= 0) {
 	    if (is_local) {
